## START: Set by rpmautospec
## (rpmautospec version 0.8.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 6;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           python-simframe
Version:        1.0.5
Release:        %autorelease
Summary:        Python framework for setting up and running scientific simulations
License:        BSD-3-Clause
URL:            https://github.com/stammler/simframe
Source:         %{pypi_source simframe}

# Install as pure-Python
# https://github.com/stammler/simframe/pull/4
Patch0:         %{url}/pull/4.patch
# Downstream-only:
# Revert "Adjusting unit tests for deprecation warning"
#
# This reverts commit 13836da8187d3c7d2565f602d77f21de063ac48b.
#
# The new atol/rtol keywords for gmres are not available before Scipy
# 0.14.0, so we must keep using the old, deprecated tol keyword.
#
# scipy-1.14.0 is available for F42+ only
# https://bugzilla.redhat.com/show_bug.cgi?id=2211813
Patch101:       0001-Revert-Adjusting-unit-tests-for-deprecation-warning.patch

BuildArch:      noarch

BuildRequires:  python3-devel
# Needed because meson.build declares the project as using the 'c' language,
# even though there are currently no C sources.
BuildRequires:  gcc

BuildRequires:  %{py3_dist pytest}
# for %%pyproject_buildrequires -p
BuildRequires:  pyproject-rpm-macros >= 1.15.1

%global _description %{expand:
Simframe is a Python framework to facilitate scientific simulations.
The scope of the software is to provide a framework which can hold
data fields, which can be used to integrate differential equations,
and which can read and write data files.}

%description %_description


%package -n python3-simframe
Summary:        %{summary}

%description -n python3-simframe %_description


%package doc
Summary:        Documentation and examples for %{name}

%description doc
%{summary}.


%prep
# Apply patches manually
%autosetup -n simframe-%{version} -N
%autopatch -M100 -p1

# Apply scipy >= 0.14 reversal patch only for F42-
%if 0%{?fedora} < 42
%patch -P101 -p1
%endif

# fix file permissions
find . -type f -perm /0111 -exec chmod -v a-x '{}' '+'


%generate_buildrequires
%pyproject_buildrequires -p


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files -L simframe


%check
# Testing exact memory usage is not portable.
k="${k-}${k+ and }not test_group_memory_usage"
%pytest -k "${k-}"
# remove installed tests
rm -rf %{buildroot}/%{python3_sitelib}/tests


%files -n python3-simframe -f %{pyproject_files}
%license LICENSE
%doc README.md


%files doc
%doc README.md
%license LICENSE
%doc examples/


%changelog
## START: Generated by rpmautospec
* Tue Jun 03 2025 Python Maint <python-maint@redhat.com> - 1.0.5-6
- Rebuilt for Python 3.14

* Sat Jan 18 2025 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Sun Jan 05 2025 Sandro <devel@penguinpee.nl> - 1.0.5-4
- Apply patch for SciPy >= 0.14 conditionally

* Mon Oct 07 2024 Karolina Surma <ksurma@redhat.com> - 1.0.5-3
- Read the runtime depedencies from pyproject.toml
- w gets the dependencies by building the wheel which is time- and
  resource-consuming. Instead, -p reads the dependencies from the [project]
  table in pyproject.toml which is a part of the sdist. This makes the
  specfile more idiomatic.

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Tue Jul 16 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.5-1
- Update to 1.0.5 (close RHBZ#2295569)

* Tue Jul 16 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.4-9
- Enable the tests

* Sun Jun 16 2024 Python Maint <python-maint@redhat.com> - 1.0.4-5
- Rebuilt for Python 3.13

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Sep 24 2023 Iztok Fister Jr. <iztok@iztok-jr-fister.eu> - 1.0.4-2
- Use SPDX

* Wed Jul 26 2023 Iztok Fister Jr. <iztok@iztok-jr-fister.eu> - 1.0.4-1
- Update to the latest release
- Do not package the tests

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Wed Jul 12 2023 Python Maint <python-maint@redhat.com> - 1.0.2-5
- Rebuilt for Python 3.12

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jun 15 2022 Python Maint <python-maint@redhat.com> - 1.0.2-2
- Rebuilt for Python 3.11

* Wed Mar 30 2022 Iztok Fister Jr. <iztokf AT fedoraproject DOT org> - 1.0.2-1
- Update to the latest release
- Remove patch

* Tue Jan 18 2022 Iztok Fister Jr. <iztokf AT fedoraproject DOT org> - 1.0.1-1
- Initial package

## END: Generated by rpmautospec
